|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r70824 - in trunk/boost/geometry: algorithms algorithms/detail/overlay extensions/algorithms/detail/overlay extensions/gis/io/veshape extensions/io/svg multi multi/algorithms
From: barend.gehrels_at_[hidden]
Date: 2011-04-01 12:38:45
Author: barendgehrels
Date: 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
New Revision: 70824
URL: http://svn.boost.org/trac/boost/changeset/70824
Log:
Renamed make_ functions return_ (centroid, buffer, envelope)
Renamed _inserter functions _insert and moved them to namespace detail (intersection, union, difference, sym_difference, simplify, convex_hull)
Added:
trunk/boost/geometry/algorithms/detail/overlay/intersection_insert.hpp
- copied, changed from r70779, /trunk/boost/geometry/algorithms/intersection_inserter.hpp
Removed:
trunk/boost/geometry/algorithms/intersection_inserter.hpp
trunk/boost/geometry/multi/algorithms/convex_hull.hpp
trunk/boost/geometry/multi/algorithms/difference.hpp
trunk/boost/geometry/multi/algorithms/union.hpp
Text files modified:
trunk/boost/geometry/algorithms/buffer.hpp | 4 +-
trunk/boost/geometry/algorithms/centroid.hpp | 8 ++--
trunk/boost/geometry/algorithms/convex_hull.hpp | 26 ++++++++++++-----
trunk/boost/geometry/algorithms/detail/overlay/intersection_insert.hpp | 59 ++++++++++++++++++++-------------------
trunk/boost/geometry/algorithms/difference.hpp | 28 ++++++++++++------
trunk/boost/geometry/algorithms/envelope.hpp | 6 ++--
trunk/boost/geometry/algorithms/intersection.hpp | 6 ++--
trunk/boost/geometry/algorithms/simplify.hpp | 33 ++++++++++++++--------
trunk/boost/geometry/algorithms/sym_difference.hpp | 24 ++++++++++-----
trunk/boost/geometry/algorithms/union.hpp | 42 ++++++++++++++-------------
trunk/boost/geometry/extensions/algorithms/detail/overlay/dissolver.hpp | 8 ++--
trunk/boost/geometry/extensions/algorithms/detail/overlay/split_rings.hpp | 2
trunk/boost/geometry/extensions/gis/io/veshape/write_veshape.hpp | 2
trunk/boost/geometry/extensions/io/svg/svg_mapper.hpp | 2
trunk/boost/geometry/multi/algorithms/intersection.hpp | 6 ++--
trunk/boost/geometry/multi/multi.hpp | 2 -
16 files changed, 147 insertions(+), 111 deletions(-)
Modified: trunk/boost/geometry/algorithms/buffer.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/buffer.hpp (original)
+++ trunk/boost/geometry/algorithms/buffer.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -133,7 +133,7 @@
/*!
\brief \brief_calc{buffer}
\ingroup buffer
-\details \details_calc{make_buffer, \det_buffer}. \details_make{buffer}.
+\details \details_calc{return_buffer, \det_buffer}. \details_return{buffer}.
\tparam Input \tparam_geometry
\tparam Output \tparam_geometry
\tparam Distance \tparam_numeric
@@ -143,7 +143,7 @@
\return \return_calc{buffer}
*/
template <typename Output, typename Input, typename T>
-Output make_buffer(Input const& geometry, T const& distance, T const& chord_length = -1)
+Output return_buffer(Input const& geometry, T const& distance, T const& chord_length = -1)
{
concept::check<Input const>();
concept::check<Output>();
Modified: trunk/boost/geometry/algorithms/centroid.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/centroid.hpp (original)
+++ trunk/boost/geometry/algorithms/centroid.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -416,7 +416,7 @@
/*!
\brief \brief_calc{centroid}
\ingroup centroid
-\details \details_calc{centroid,geometric center (or: center of mass)}. \details_make{centroid}.
+\details \details_calc{centroid,geometric center (or: center of mass)}. \details_return{centroid}.
\tparam Point \tparam_point
\tparam Geometry \tparam_geometry
\param geometry \param_geometry
@@ -425,7 +425,7 @@
\qbk{[include reference/algorithms/centroid.qbk]}
*/
template<typename Point, typename Geometry>
-inline Point make_centroid(Geometry const& geometry)
+inline Point return_centroid(Geometry const& geometry)
{
concept::check_concepts_and_equal_dimensions<Point, Geometry const>();
@@ -437,7 +437,7 @@
/*!
\brief \brief_calc{centroid} \brief_strategy
\ingroup centroid
-\details \details_calc{centroid,geometric center (or: center of mass)}. \details_make{centroid}. \details_strategy_reasons
+\details \details_calc{centroid,geometric center (or: center of mass)}. \details_return{centroid}. \details_strategy_reasons
\tparam Point \tparam_point
\tparam Geometry \tparam_geometry
\tparam Strategy \tparam_strategy{centroid}
@@ -450,7 +450,7 @@
\qbk{[include reference/algorithms/centroid_strategies.qbk]}
*/
template<typename Point, typename Geometry, typename Strategy>
-inline Point make_centroid(Geometry const& geometry, Strategy const& strategy)
+inline Point return_centroid(Geometry const& geometry, Strategy const& strategy)
{
//BOOST_CONCEPT_ASSERT( (geometry::concept::CentroidStrategy<Strategy>) );
Modified: trunk/boost/geometry/algorithms/convex_hull.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/convex_hull.hpp (original)
+++ trunk/boost/geometry/algorithms/convex_hull.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -43,7 +43,7 @@
order_selector Order,
typename Strategy
>
-struct hull_inserter
+struct hull_insert
{
// Member template function, to avoid inconvenient declaration
@@ -71,7 +71,7 @@
static inline void apply(Geometry const& geometry, OutputGeometry& out,
Strategy const& strategy)
{
- hull_inserter
+ hull_insert
<
Geometry,
geometry::point_order<OutputGeometry>::value,
@@ -114,8 +114,8 @@
order_selector Order,
typename GeometryIn, typename Strategy
>
-struct convex_hull_inserter
- : detail::convex_hull::hull_inserter<GeometryIn, Order, Strategy>
+struct convex_hull_insert
+ : detail::convex_hull::hull_insert<GeometryIn, Order, Strategy>
{};
@@ -178,9 +178,13 @@
convex_hull(geometry, hull, strategy_type());
}
+#ifndef DOXYGEN_NO_DETAIL
+namespace detail { namespace convex_hull
+{
+
template<typename Geometry, typename OutputIterator, typename Strategy>
-inline OutputIterator convex_hull_inserter(Geometry const& geometry,
+inline OutputIterator convex_hull_insert(Geometry const& geometry,
OutputIterator out, Strategy const& strategy)
{
// Concept: output point type = point type of input geometry
@@ -189,7 +193,7 @@
BOOST_CONCEPT_ASSERT( (geometry::concept::ConvexHullStrategy<Strategy>) );
- return dispatch::convex_hull_inserter
+ return dispatch::convex_hull_insert
<
typename tag<Geometry>::type,
geometry::point_order<Geometry>::value,
@@ -212,7 +216,7 @@
*/
template<typename Geometry, typename OutputIterator>
-inline OutputIterator convex_hull_inserter(Geometry const& geometry,
+inline OutputIterator convex_hull_insert(Geometry const& geometry,
OutputIterator out)
{
// Concept: output point type = point type of input geometry
@@ -229,10 +233,16 @@
point_type
>::type strategy_type;
- return convex_hull_inserter(geometry, out, strategy_type());
+ return convex_hull_insert(geometry, out, strategy_type());
}
+}} // namespace detail::convex_hull
+#endif // DOXYGEN_NO_DETAIL
+
+
+
+
}} // namespace boost::geometry
Copied: trunk/boost/geometry/algorithms/detail/overlay/intersection_insert.hpp (from r70779, /trunk/boost/geometry/algorithms/intersection_inserter.hpp)
==============================================================================
--- /trunk/boost/geometry/algorithms/intersection_inserter.hpp (original)
+++ trunk/boost/geometry/algorithms/detail/overlay/intersection_insert.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -6,8 +6,8 @@
// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
-#ifndef BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
-#define BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
+#ifndef BOOST_GEOMETRY_ALGORITHMS_DETAIL_OVERLAY_INTERSECTION_INSERT_HPP
+#define BOOST_GEOMETRY_ALGORITHMS_DETAIL_OVERLAY_INTERSECTION_INSERT_HPP
#include <cstddef>
@@ -126,7 +126,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
{
BOOST_MPL_ASSERT_MSG
(
@@ -146,7 +146,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
TagIn1, TagIn2, TagOut,
true, true, true,
@@ -171,7 +171,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
TagIn, box_tag, TagOut,
true, true, true,
@@ -193,7 +193,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
segment_tag, segment_tag, point_tag,
false, false, false,
@@ -218,7 +218,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
linestring_tag, linestring_tag, point_tag,
false, false, false,
@@ -243,7 +243,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
linestring_tag, box_tag, linestring_tag,
false, true, false,
@@ -272,7 +272,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
segment_tag, box_tag, linestring_tag,
false, true, false,
@@ -307,13 +307,13 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter_reversed
+struct intersection_insert_reversed
{
static inline OutputIterator apply(Geometry1 const& g1,
Geometry2 const& g2, OutputIterator out,
Strategy const& strategy)
{
- return intersection_inserter
+ return intersection_insert
<
GeometryTag2, GeometryTag1, GeometryTag3,
Areal2, Areal1, ArealOut,
@@ -346,7 +346,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator inserter(Geometry1 const& geometry1,
+inline OutputIterator insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out,
Strategy const& strategy)
@@ -354,7 +354,7 @@
return boost::mpl::if_c
<
geometry::reverse_dispatch<Geometry1, Geometry2>::type::value,
- geometry::dispatch::intersection_inserter_reversed
+ geometry::dispatch::intersection_insert_reversed
<
typename geometry::tag<Geometry1>::type,
typename geometry::tag<Geometry2>::type,
@@ -370,7 +370,7 @@
OverlayType,
Strategy
>,
- geometry::dispatch::intersection_inserter
+ geometry::dispatch::intersection_insert
<
typename geometry::tag<Geometry1>::type,
typename geometry::tag<Geometry2>::type,
@@ -379,9 +379,9 @@
geometry::is_areal<Geometry2>::value,
geometry::is_areal<GeometryOut>::value,
Geometry1, Geometry2,
- overlay::do_reverse<geometry::point_order<Geometry1>::value>::value,
- overlay::do_reverse<geometry::point_order<Geometry2>::value, ReverseSecond>::value,
- overlay::do_reverse<geometry::point_order<GeometryOut>::value>::value,
+ geometry::detail::overlay::do_reverse<geometry::point_order<Geometry1>::value>::value,
+ geometry::detail::overlay::do_reverse<geometry::point_order<Geometry2>::value, ReverseSecond>::value,
+ geometry::detail::overlay::do_reverse<geometry::point_order<GeometryOut>::value>::value,
OutputIterator, GeometryOut,
OverlayType,
Strategy
@@ -390,14 +390,11 @@
}
-}} // namespace detail::intersection
-#endif // DOXYGEN_NO_DETAIL
-
/*!
\brief \brief_calc2{intersection} \brief_strategy
\ingroup intersection
-\details \details_calc2{intersection_inserter, spatial set theoretic intersection}
- \brief_strategy. \details_inserter{intersection}
+\details \details_calc2{intersection_insert, spatial set theoretic intersection}
+ \brief_strategy. \details_insert{intersection}
\tparam GeometryOut \tparam_geometry{\p_l_or_c}
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -420,7 +417,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator intersection_inserter(Geometry1 const& geometry1,
+inline OutputIterator intersection_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out,
Strategy const& strategy)
@@ -428,7 +425,7 @@
concept::check<Geometry1 const>();
concept::check<Geometry2 const>();
- return detail::intersection::inserter
+ return detail::intersection::insert
<
GeometryOut, false, overlay_intersection
>(geometry1, geometry2, out, strategy);
@@ -438,8 +435,8 @@
/*!
\brief \brief_calc2{intersection}
\ingroup intersection
-\details \details_calc2{intersection_inserter, spatial set theoretic intersection}.
- \details_inserter{intersection}
+\details \details_calc2{intersection_insert, spatial set theoretic intersection}.
+ \details_insert{intersection}
\tparam GeometryOut \tparam_geometry{\p_l_or_c}
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -458,7 +455,7 @@
typename Geometry2,
typename OutputIterator
>
-inline OutputIterator intersection_inserter(Geometry1 const& geometry1,
+inline OutputIterator intersection_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out)
{
@@ -473,12 +470,16 @@
typename geometry::point_type<GeometryOut>::type
> strategy;
- return intersection_inserter<GeometryOut>(geometry1, geometry2, out,
+ return intersection_insert<GeometryOut>(geometry1, geometry2, out,
strategy());
}
+}} // namespace detail::intersection
+#endif // DOXYGEN_NO_DETAIL
+
+
}} // namespace boost::geometry
-#endif // BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
+#endif // BOOST_GEOMETRY_ALGORITHMS_DETAIL_OVERLAY_INTERSECTION_INSERT_HPP
Modified: trunk/boost/geometry/algorithms/difference.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/difference.hpp (original)
+++ trunk/boost/geometry/algorithms/difference.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -11,16 +11,19 @@
#include <algorithm>
-#include <boost/geometry/algorithms/intersection_inserter.hpp>
+#include <boost/geometry/algorithms/detail/overlay/intersection_insert.hpp>
namespace boost { namespace geometry
{
+#ifndef DOXYGEN_NO_DETAIL
+namespace detail { namespace difference
+{
/*!
\brief_calc2{difference} \brief_strategy
\ingroup difference
-\details \details_calc2{difference_inserter, spatial set theoretic difference}
+\details \details_calc2{difference_insert, spatial set theoretic difference}
\brief_strategy. \details_inserter{difference}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
@@ -43,7 +46,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator difference_inserter(Geometry1 const& geometry1,
+inline OutputIterator difference_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2, OutputIterator out,
Strategy const& strategy)
{
@@ -51,7 +54,7 @@
concept::check<Geometry2 const>();
concept::check<GeometryOut>();
- return detail::intersection::inserter<GeometryOut, true, overlay_difference>(
+ return detail::intersection::insert<GeometryOut, true, overlay_difference>(
geometry1, geometry2,
out,
strategy);
@@ -60,8 +63,8 @@
/*!
\brief_calc2{difference}
\ingroup difference
-\details \details_calc2{difference_inserter, spatial set theoretic difference}.
- \details_inserter{difference}
+\details \details_calc2{difference_insert, spatial set theoretic difference}.
+ \details_insert{difference}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -71,7 +74,7 @@
\param out \param_out{difference}
\return \return_out
-\qbk{[include reference/algorithms/difference_inserter.qbk]}
+\qbk{[include reference/algorithms/difference_insert.qbk]}
*/
template
<
@@ -80,7 +83,7 @@
typename Geometry2,
typename OutputIterator
>
-inline OutputIterator difference_inserter(Geometry1 const& geometry1,
+inline OutputIterator difference_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2, OutputIterator out)
{
concept::check<Geometry1 const>();
@@ -95,11 +98,16 @@
typename geometry::point_type<GeometryOut>::type
> strategy;
- return difference_inserter<GeometryOut>(geometry1, geometry2,
+ return difference_insert<GeometryOut>(geometry1, geometry2,
out, strategy());
}
+}} // namespace detail::difference
+#endif // DOXYGEN_NO_DETAIL
+
+
+
/*!
\brief_calc2{difference}
\ingroup difference
@@ -128,7 +136,7 @@
typedef typename boost::range_value<Collection>::type geometry_out;
concept::check<geometry_out>();
- difference_inserter<geometry_out>(
+ detail::difference::difference_insert<geometry_out>(
geometry1, geometry2,
std::back_inserter(output_collection));
}
Modified: trunk/boost/geometry/algorithms/envelope.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/envelope.hpp (original)
+++ trunk/boost/geometry/algorithms/envelope.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -247,7 +247,7 @@
/*!
\brief \brief_calc{envelope}
\ingroup envelope
-\details \details_calc{make_envelope,\det_envelope}. \details_make{envelope}
+\details \details_calc{return_envelope,\det_envelope}. \details_return{envelope}
\tparam Box \tparam_box
\tparam Geometry \tparam_geometry
\param geometry \param_geometry
@@ -255,11 +255,11 @@
\qbk{
[heading Example]
-[make_envelope] [make_envelope_output]
+[return_envelope] [return_envelope_output]
}
*/
template<typename Box, typename Geometry>
-inline Box make_envelope(Geometry const& geometry)
+inline Box return_envelope(Geometry const& geometry)
{
concept::check<Geometry const>();
concept::check<Box>();
Modified: trunk/boost/geometry/algorithms/intersection.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/intersection_inserter.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
+++ (empty file)
@@ -1,484 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-
-// Copyright (c) 2007-2011 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#ifndef BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
-#define BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
-
-
-#include <cstddef>
-
-#include <boost/mpl/if.hpp>
-#include <boost/mpl/assert.hpp>
-#include <boost/range/metafunctions.hpp>
-
-
-#include <boost/geometry/core/is_areal.hpp>
-#include <boost/geometry/core/point_order.hpp>
-#include <boost/geometry/core/reverse_dispatch.hpp>
-#include <boost/geometry/geometries/concepts/check.hpp>
-#include <boost/geometry/algorithms/convert.hpp>
-#include <boost/geometry/algorithms/detail/overlay/clip_linestring.hpp>
-#include <boost/geometry/algorithms/detail/overlay/get_intersection_points.hpp>
-#include <boost/geometry/algorithms/detail/overlay/overlay.hpp>
-#include <boost/geometry/algorithms/detail/overlay/overlay_type.hpp>
-#include <boost/geometry/ranges/segment_range.hpp>
-
-
-namespace boost { namespace geometry
-{
-
-#ifndef DOXYGEN_NO_DETAIL
-namespace detail { namespace intersection
-{
-
-template
-<
- typename Segment1, typename Segment2,
- typename OutputIterator, typename PointOut,
- typename Strategy
->
-struct intersection_segment_segment_point
-{
- static inline OutputIterator apply(Segment1 const& segment1,
- Segment2 const& segment2, OutputIterator out,
- Strategy const& strategy)
- {
- typedef typename point_type<PointOut>::type point_type;
-
- // Get the intersection point (or two points)
- segment_intersection_points<point_type> is
- = strategy::intersection::relate_cartesian_segments
- <
- policies::relate::segments_intersection_points
- <
- Segment1,
- Segment2,
- segment_intersection_points<point_type>
- >
- >::apply(segment1, segment2);
-
- for (std::size_t i = 0; i < is.count; i++)
- {
- PointOut p;
- geometry::convert(is.intersections[i], p);
- *out++ = p;
- }
- return out;
- }
-};
-
-template
-<
- typename Linestring1, typename Linestring2,
- typename OutputIterator, typename PointOut,
- typename Strategy
->
-struct intersection_linestring_linestring_point
-{
- static inline OutputIterator apply(Linestring1 const& linestring1,
- Linestring2 const& linestring2, OutputIterator out,
- Strategy const& strategy)
- {
- typedef typename point_type<PointOut>::type point_type;
-
- typedef detail::overlay::turn_info<point_type> turn_info;
- std::deque<turn_info> turns;
-
- geometry::get_intersection_points(linestring1, linestring2, turns);
-
- for (typename boost::range_iterator<std::deque<turn_info> const>::type
- it = boost::begin(turns); it != boost::end(turns); ++it)
- {
- PointOut p;
- geometry::convert(it->point, p);
- *out++ = p;
- }
- return out;
- }
-};
-
-}} // namespace detail::intersection
-#endif // DOXYGEN_NO_DETAIL
-
-
-
-#ifndef DOXYGEN_NO_DISPATCH
-namespace dispatch
-{
-
-template
-<
- // tag dispatching:
- typename TagIn1, typename TagIn2, typename TagOut,
- // orientation
- // metafunction finetuning helpers:
- bool Areal1, bool Areal2, bool ArealOut,
- // real types
- typename Geometry1, typename Geometry2,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator,
- typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
-{
- BOOST_MPL_ASSERT_MSG
- (
- false, NOT_OR_NOT_YET_IMPLEMENTED_FOR_THIS_GEOMETRY_TYPES_OR_ORIENTATIONS
- , (types<Geometry1, Geometry2, GeometryOut>)
- );
-};
-
-
-template
-<
- typename TagIn1, typename TagIn2, typename TagOut,
- typename Geometry1, typename Geometry2,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator,
- typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- TagIn1, TagIn2, TagOut,
- true, true, true,
- Geometry1, Geometry2,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- > : detail::overlay::overlay
- <Geometry1, Geometry2, Reverse1, Reverse2, ReverseOut, OutputIterator, GeometryOut, OverlayType, Strategy>
-{};
-
-
-// Any areal type with box:
-template
-<
- typename TagIn, typename TagOut,
- typename Geometry, typename Box,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator,
- typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- TagIn, box_tag, TagOut,
- true, true, true,
- Geometry, Box,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- > : detail::overlay::overlay
- <Geometry, Box, Reverse1, Reverse2, ReverseOut, OutputIterator, GeometryOut, OverlayType, Strategy>
-{};
-
-
-template
-<
- typename Segment1, typename Segment2,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator, typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- segment_tag, segment_tag, point_tag,
- false, false, false,
- Segment1, Segment2,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType, Strategy
- > : detail::intersection::intersection_segment_segment_point
- <
- Segment1, Segment2,
- OutputIterator, GeometryOut,
- Strategy
- >
-{};
-
-
-template
-<
- typename Linestring1, typename Linestring2,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator, typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- linestring_tag, linestring_tag, point_tag,
- false, false, false,
- Linestring1, Linestring2,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType, Strategy
- > : detail::intersection::intersection_linestring_linestring_point
- <
- Linestring1, Linestring2,
- OutputIterator, GeometryOut,
- Strategy
- >
-{};
-
-
-template
-<
- typename Linestring, typename Box,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator, typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- linestring_tag, box_tag, linestring_tag,
- false, true, false,
- Linestring, Box,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- >
-{
- static inline OutputIterator apply(Linestring const& linestring,
- Box const& box, OutputIterator out, Strategy const& strategy)
- {
- typedef typename point_type<GeometryOut>::type point_type;
- strategy::intersection::liang_barsky<Box, point_type> lb_strategy;
- return detail::intersection::clip_range_with_box
- <GeometryOut>(box, linestring, out, lb_strategy);
- }
-};
-
-template
-<
- typename Segment, typename Box,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator, typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter
- <
- segment_tag, box_tag, linestring_tag,
- false, true, false,
- Segment, Box,
- Reverse1, Reverse2, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- >
-{
- static inline OutputIterator apply(Segment const& segment,
- Box const& box, OutputIterator out, Strategy const& strategy)
- {
- typedef geometry::segment_range<Segment> range_type;
- range_type range(segment);
-
- typedef typename point_type<GeometryOut>::type point_type;
- strategy::intersection::liang_barsky<Box, point_type> lb_strategy;
- return detail::intersection::clip_range_with_box
- <GeometryOut>(box, range, out, lb_strategy);
- }
-};
-
-
-template
-<
- typename GeometryTag1, typename GeometryTag2, typename GeometryTag3,
- bool Areal1, bool Areal2, bool ArealOut,
- typename Geometry1, typename Geometry2,
- bool Reverse1, bool Reverse2, bool ReverseOut,
- typename OutputIterator, typename GeometryOut,
- overlay_type OverlayType,
- typename Strategy
->
-struct intersection_inserter_reversed
-{
- static inline OutputIterator apply(Geometry1 const& g1,
- Geometry2 const& g2, OutputIterator out,
- Strategy const& strategy)
- {
- return intersection_inserter
- <
- GeometryTag2, GeometryTag1, GeometryTag3,
- Areal2, Areal1, ArealOut,
- Geometry2, Geometry1,
- Reverse2, Reverse1, ReverseOut,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- >::apply(g2, g1, out, strategy);
- }
-};
-
-
-
-} // namespace dispatch
-#endif // DOXYGEN_NO_DISPATCH
-
-
-#ifndef DOXYGEN_NO_DETAIL
-namespace detail { namespace intersection
-{
-
-
-template
-<
- typename GeometryOut,
- bool ReverseSecond,
- overlay_type OverlayType,
- typename Geometry1, typename Geometry2,
- typename OutputIterator,
- typename Strategy
->
-inline OutputIterator inserter(Geometry1 const& geometry1,
- Geometry2 const& geometry2,
- OutputIterator out,
- Strategy const& strategy)
-{
- return boost::mpl::if_c
- <
- geometry::reverse_dispatch<Geometry1, Geometry2>::type::value,
- geometry::dispatch::intersection_inserter_reversed
- <
- typename geometry::tag<Geometry1>::type,
- typename geometry::tag<Geometry2>::type,
- typename geometry::tag<GeometryOut>::type,
- geometry::is_areal<Geometry1>::value,
- geometry::is_areal<Geometry2>::value,
- geometry::is_areal<GeometryOut>::value,
- Geometry1, Geometry2,
- overlay::do_reverse<geometry::point_order<Geometry1>::value>::value,
- overlay::do_reverse<geometry::point_order<Geometry2>::value, ReverseSecond>::value,
- overlay::do_reverse<geometry::point_order<GeometryOut>::value>::value,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- >,
- geometry::dispatch::intersection_inserter
- <
- typename geometry::tag<Geometry1>::type,
- typename geometry::tag<Geometry2>::type,
- typename geometry::tag<GeometryOut>::type,
- geometry::is_areal<Geometry1>::value,
- geometry::is_areal<Geometry2>::value,
- geometry::is_areal<GeometryOut>::value,
- Geometry1, Geometry2,
- overlay::do_reverse<geometry::point_order<Geometry1>::value>::value,
- overlay::do_reverse<geometry::point_order<Geometry2>::value, ReverseSecond>::value,
- overlay::do_reverse<geometry::point_order<GeometryOut>::value>::value,
- OutputIterator, GeometryOut,
- OverlayType,
- Strategy
- >
- >::type::apply(geometry1, geometry2, out, strategy);
-}
-
-
-}} // namespace detail::intersection
-#endif // DOXYGEN_NO_DETAIL
-
-/*!
-\brief \brief_calc2{intersection} \brief_strategy
-\ingroup intersection
-\details \details_calc2{intersection_inserter, spatial set theoretic intersection}
- \brief_strategy. \details_inserter{intersection}
-\tparam GeometryOut \tparam_geometry{\p_l_or_c}
-\tparam Geometry1 \tparam_geometry
-\tparam Geometry2 \tparam_geometry
-\tparam OutputIterator \tparam_out{\p_l_or_c}
-\tparam Strategy \tparam_strategy_overlay
-\param geometry1 \param_geometry
-\param geometry2 \param_geometry
-\param out \param_out{intersection}
-\param strategy \param_strategy{intersection}
-\return \return_out
-
-\qbk{distinguish,with strategy}
-\qbk{[include reference/algorithms/intersection.qbk]}
-*/
-template
-<
- typename GeometryOut,
- typename Geometry1,
- typename Geometry2,
- typename OutputIterator,
- typename Strategy
->
-inline OutputIterator intersection_inserter(Geometry1 const& geometry1,
- Geometry2 const& geometry2,
- OutputIterator out,
- Strategy const& strategy)
-{
- concept::check<Geometry1 const>();
- concept::check<Geometry2 const>();
-
- return detail::intersection::inserter
- <
- GeometryOut, false, overlay_intersection
- >(geometry1, geometry2, out, strategy);
-}
-
-
-/*!
-\brief \brief_calc2{intersection}
-\ingroup intersection
-\details \details_calc2{intersection_inserter, spatial set theoretic intersection}.
- \details_inserter{intersection}
-\tparam GeometryOut \tparam_geometry{\p_l_or_c}
-\tparam Geometry1 \tparam_geometry
-\tparam Geometry2 \tparam_geometry
-\tparam OutputIterator \tparam_out{\p_l_or_c}
-\param geometry1 \param_geometry
-\param geometry2 \param_geometry
-\param out \param_out{intersection}
-\return \return_out
-
-\qbk{[include reference/algorithms/intersection.qbk]}
-*/
-template
-<
- typename GeometryOut,
- typename Geometry1,
- typename Geometry2,
- typename OutputIterator
->
-inline OutputIterator intersection_inserter(Geometry1 const& geometry1,
- Geometry2 const& geometry2,
- OutputIterator out)
-{
- concept::check<Geometry1 const>();
- concept::check<Geometry2 const>();
-
- typedef strategy_intersection
- <
- typename cs_tag<GeometryOut>::type,
- Geometry1,
- Geometry2,
- typename geometry::point_type<GeometryOut>::type
- > strategy;
-
- return intersection_inserter<GeometryOut>(geometry1, geometry2, out,
- strategy());
-}
-
-
-}} // namespace boost::geometry
-
-
-#endif // BOOST_GEOMETRY_ALGORITHMS_INTERSECTION_INSERTER_HPP
Modified: trunk/boost/geometry/algorithms/simplify.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/simplify.hpp (original)
+++ trunk/boost/geometry/algorithms/simplify.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -44,7 +44,7 @@
{
template<typename Range, typename Strategy>
-struct simplify_range_inserter
+struct simplify_range_insert
{
template <typename OutputIterator, typename Distance>
static inline void apply(Range const& range, OutputIterator out,
@@ -108,7 +108,7 @@
}
else
{
- simplify_range_inserter<Range, Strategy>::apply
+ simplify_range_insert<Range, Strategy>::apply
(
range, std::back_inserter(out), max_distance, strategy
);
@@ -220,14 +220,14 @@
template <typename Tag, typename Geometry, typename Strategy>
-struct simplify_inserter
+struct simplify_insert
{
};
template <typename Linestring, typename Strategy>
-struct simplify_inserter<linestring_tag, Linestring, Strategy>
- : detail::simplify::simplify_range_inserter
+struct simplify_insert<linestring_tag, Linestring, Strategy>
+ : detail::simplify::simplify_range_insert
<
Linestring,
Strategy
@@ -235,8 +235,8 @@
{};
template <typename Ring, typename Strategy>
-struct simplify_inserter<ring_tag, Ring, Strategy>
- : detail::simplify::simplify_range_inserter
+struct simplify_insert<ring_tag, Ring, Strategy>
+ : detail::simplify::simplify_range_insert
<
Ring,
Strategy
@@ -321,6 +321,11 @@
}
+#ifndef DOXYGEN_NO_DETAIL
+namespace detail { namespace simplify
+{
+
+
/*!
\brief Simplify a geometry, using an output iterator
and a specified strategy
@@ -337,13 +342,13 @@
\qbk{[include reference/algorithms/simplify.qbk]}
*/
template<typename Geometry, typename OutputIterator, typename Distance, typename Strategy>
-inline void simplify_inserter(Geometry const& geometry, OutputIterator out,
+inline void simplify_insert(Geometry const& geometry, OutputIterator out,
Distance const& max_distance, Strategy const& strategy)
{
concept::check<Geometry const>();
BOOST_CONCEPT_ASSERT( (geometry::concept::SimplifyStrategy<Strategy>) );
- dispatch::simplify_inserter
+ dispatch::simplify_insert
<
typename tag<Geometry>::type,
Geometry,
@@ -360,10 +365,10 @@
\param max_distance distance (in units of input coordinates) of a vertex
to other segments to be removed
-\qbk{[include reference/algorithms/simplify_inserter.qbk]}
+\qbk{[include reference/algorithms/simplify_insert.qbk]}
*/
template<typename Geometry, typename OutputIterator, typename Distance>
-inline void simplify_inserter(Geometry const& geometry, OutputIterator out,
+inline void simplify_insert(Geometry const& geometry, OutputIterator out,
Distance const& max_distance)
{
typedef typename point_type<Geometry>::type point_type;
@@ -382,7 +387,7 @@
point_type, ds_strategy_type
> strategy_type;
- dispatch::simplify_inserter
+ dispatch::simplify_insert
<
typename tag<Geometry>::type,
Geometry,
@@ -390,6 +395,10 @@
>::apply(geometry, out, max_distance, strategy_type());
}
+}} // namespace detail::simplify
+#endif // DOXYGEN_NO_DETAIL
+
+
}} // namespace boost::geometry
Modified: trunk/boost/geometry/algorithms/sym_difference.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/sym_difference.hpp (original)
+++ trunk/boost/geometry/algorithms/sym_difference.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -18,12 +18,17 @@
namespace boost { namespace geometry
{
+#ifndef DOXYGEN_NO_DETAIL
+namespace detail { namespace sym_difference
+{
+
+
/*!
\brief \brief_calc2{symmetric difference} \brief_strategy
\ingroup sym_difference
\details \details_calc2{symmetric difference, spatial set theoretic symmetric difference (XOR)}
- \brief_strategy. \details_inserter{sym_difference}
+ \brief_strategy. \details_insert{sym_difference}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -44,7 +49,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator sym_difference_inserter(Geometry1 const& geometry1,
+inline OutputIterator sym_difference_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2, OutputIterator out,
Strategy const& strategy)
{
@@ -52,9 +57,9 @@
concept::check<Geometry2 const>();
concept::check<GeometryOut>();
- out = detail::intersection::inserter<GeometryOut, true, overlay_difference>(
+ out = detail::intersection::insert<GeometryOut, true, overlay_difference>(
geometry1, geometry2, out, strategy);
- out = detail::intersection::inserter<GeometryOut, true, overlay_difference>(
+ out = detail::intersection::insert<GeometryOut, true, overlay_difference>(
geometry2, geometry1, out, strategy);
return out;
}
@@ -64,7 +69,7 @@
\brief \brief_calc2{symmetric difference}
\ingroup sym_difference
\details \details_calc2{symmetric difference, spatial set theoretic symmetric difference (XOR)}
- \details_inserter{sym_difference}
+ \details_insert{sym_difference}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -81,7 +86,7 @@
typename Geometry2,
typename OutputIterator
>
-inline OutputIterator sym_difference_inserter(Geometry1 const& geometry1,
+inline OutputIterator sym_difference_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2, OutputIterator out)
{
concept::check<Geometry1 const>();
@@ -96,9 +101,12 @@
typename geometry::point_type<GeometryOut>::type
> strategy_type;
- return sym_difference_inserter<GeometryOut>(geometry1, geometry2, out, strategy_type());
+ return sym_difference_insert<GeometryOut>(geometry1, geometry2, out, strategy_type());
}
+}} // namespace detail::sym_difference
+#endif // DOXYGEN_NO_DETAIL
+
/*!
\brief \brief_calc2{symmetric difference}
@@ -129,7 +137,7 @@
typedef typename boost::range_value<Collection>::type geometry_out;
concept::check<geometry_out>();
- sym_difference_inserter<geometry_out>(
+ detail::sym_difference::sym_difference_insert<geometry_out>(
geometry1, geometry2,
std::back_inserter(output_collection));
}
Modified: trunk/boost/geometry/algorithms/union.hpp
==============================================================================
--- trunk/boost/geometry/algorithms/union.hpp (original)
+++ trunk/boost/geometry/algorithms/union.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -41,7 +41,7 @@
typename GeometryOut,
typename Strategy
>
-struct union_inserter
+struct union_insert
{
BOOST_MPL_ASSERT_MSG
(
@@ -60,7 +60,7 @@
typename GeometryOut,
typename Strategy
>
-struct union_inserter
+struct union_insert
<
TagIn1, TagIn2, TagOut,
true, true, true,
@@ -83,13 +83,13 @@
typename OutputIterator, typename GeometryOut,
typename Strategy
>
-struct union_inserter_reversed
+struct union_insert_reversed
{
static inline OutputIterator apply(Geometry1 const& g1,
Geometry2 const& g2, OutputIterator out,
Strategy const& strategy)
{
- return union_inserter
+ return union_insert
<
GeometryTag2, GeometryTag1, GeometryTag3,
Areal2, Areal1, ArealOut,
@@ -116,7 +116,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator inserter(Geometry1 const& geometry1,
+inline OutputIterator insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out,
Strategy const& strategy)
@@ -124,7 +124,7 @@
return boost::mpl::if_c
<
geometry::reverse_dispatch<Geometry1, Geometry2>::type::value,
- dispatch::union_inserter_reversed
+ dispatch::union_insert_reversed
<
typename tag<Geometry1>::type,
typename tag<Geometry2>::type,
@@ -139,7 +139,7 @@
OutputIterator, GeometryOut,
Strategy
>,
- dispatch::union_inserter
+ dispatch::union_insert
<
typename tag<Geometry1>::type,
typename tag<Geometry2>::type,
@@ -157,15 +157,11 @@
>::type::apply(geometry1, geometry2, out, strategy);
}
-}} // namespace detail::union_
-#endif // DOXYGEN_NO_DETAIL
-
-
/*!
\brief_calc2{union} \brief_strategy
\ingroup union
-\details \details_calc2{union_inserter, spatial set theoretic union}
- \brief_strategy. details_inserter{union}
+\details \details_calc2{union_insert, spatial set theoretic union}
+ \brief_strategy. details_insert{union}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -187,7 +183,7 @@
typename OutputIterator,
typename Strategy
>
-inline OutputIterator union_inserter(Geometry1 const& geometry1,
+inline OutputIterator union_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out,
Strategy const& strategy)
@@ -196,14 +192,14 @@
concept::check<Geometry2 const>();
concept::check<GeometryOut>();
- return detail::union_::inserter<GeometryOut>(geometry1, geometry2, out, strategy);
+ return detail::union_::insert<GeometryOut>(geometry1, geometry2, out, strategy);
}
/*!
\brief_calc2{union}
\ingroup union
-\details \details_calc2{union_inserter, spatial set theoretic union}.
- \details_inserter{union}
+\details \details_calc2{union_insert, spatial set theoretic union}.
+ \details_insert{union}
\tparam GeometryOut output geometry type, must be specified
\tparam Geometry1 \tparam_geometry
\tparam Geometry2 \tparam_geometry
@@ -220,7 +216,7 @@
typename Geometry2,
typename OutputIterator
>
-inline OutputIterator union_inserter(Geometry1 const& geometry1,
+inline OutputIterator union_insert(Geometry1 const& geometry1,
Geometry2 const& geometry2,
OutputIterator out)
{
@@ -236,10 +232,16 @@
typename geometry::point_type<GeometryOut>::type
> strategy;
- return union_inserter<GeometryOut>(geometry1, geometry2, out, strategy());
+ return union_insert<GeometryOut>(geometry1, geometry2, out, strategy());
}
+}} // namespace detail::union_
+#endif // DOXYGEN_NO_DETAIL
+
+
+
+
/*!
\brief Combines two geometries which each other
\ingroup union
@@ -271,7 +273,7 @@
typedef typename boost::range_value<Collection>::type geometry_out;
concept::check<geometry_out>();
- union_inserter<geometry_out>(geometry1, geometry2,
+ detail::union_::union_insert<geometry_out>(geometry1, geometry2,
std::back_inserter(output_collection));
}
Modified: trunk/boost/geometry/extensions/algorithms/detail/overlay/dissolver.hpp
==============================================================================
--- trunk/boost/geometry/extensions/algorithms/detail/overlay/dissolver.hpp (original)
+++ trunk/boost/geometry/extensions/algorithms/detail/overlay/dissolver.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -190,8 +190,8 @@
typedef typename geometry::point_type<Geometry2>::type point_type;
std::cout << "Combine "
<< area_a << " with " << " " << area_b
- << " { " << geometry::wkt(geometry::make_centroid<point_type>(a))
- << geometry::wkt(geometry::make_centroid<point_type>(b)) << " }"
+ << " { " << geometry::wkt(geometry::return_centroid<point_type>(a))
+ << geometry::wkt(geometry::return_centroid<point_type>(b)) << " }"
<< std::endl;
*/
// END DEBUG
@@ -219,7 +219,7 @@
typedef typename geometry::point_type<Geometry2>::type point_type;
std::cout << "Result "
<< geometry::area(output_collection[i])
- << " " << geometry::wkt(geometry::make_centroid<point_type>(output_collection[i]))
+ << " " << geometry::wkt(geometry::return_centroid<point_type>(output_collection[i]))
<< std::endl;
}
*/
@@ -287,7 +287,7 @@
++it, ++index)
{
helper.push_back(dissolve_helper<box_type>(index,
- geometry::make_envelope<box_type>(*it),
+ geometry::return_envelope<box_type>(*it),
geometry::area(*it),
source));
}
Modified: trunk/boost/geometry/extensions/algorithms/detail/overlay/split_rings.hpp
==============================================================================
--- trunk/boost/geometry/extensions/algorithms/detail/overlay/split_rings.hpp (original)
+++ trunk/boost/geometry/extensions/algorithms/detail/overlay/split_rings.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -233,7 +233,7 @@
{
inline split_turn_operation()
: detail::overlay::turn_operation()
- , distance(geometry::make_distance_result<distance_type>(0))
+ , distance(geometry::return_distance_result<distance_type>(0))
{}
typedef typename distance_result<P, P>::type distance_type;
Modified: trunk/boost/geometry/extensions/gis/io/veshape/write_veshape.hpp
==============================================================================
--- trunk/boost/geometry/extensions/gis/io/veshape/write_veshape.hpp (original)
+++ trunk/boost/geometry/extensions/gis/io/veshape/write_veshape.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -267,7 +267,7 @@
\brief Object generator to conveniently stream objects without including streamveshape
\ingroup veshape
\par Example:
-Small example showing how to use the make_veshape helper function
+Small example showing how to use the veshape helper function
\dontinclude doxygen_1.cpp
\skip example_as_veshape_vector
\line {
Modified: trunk/boost/geometry/extensions/io/svg/svg_mapper.hpp
==============================================================================
--- trunk/boost/geometry/extensions/io/svg/svg_mapper.hpp (original)
+++ trunk/boost/geometry/extensions/io/svg/svg_mapper.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -266,7 +266,7 @@
if (num_points(geometry) > 0)
{
expand(m_bounding_box,
- make_envelope
+ return_envelope
<
model::box<Point>
>(geometry));
Deleted: trunk/boost/geometry/multi/algorithms/convex_hull.hpp
==============================================================================
--- trunk/boost/geometry/multi/algorithms/convex_hull.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
+++ (empty file)
@@ -1,28 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-
-// Copyright (c) 2007-2011 Barend Gehrels, Amsterdam, the Netherlands.
-// Copyright (c) 2008-2011 Bruno Lalande, Paris, France.
-// Copyright (c) 2009-2011 Mateusz Loskot, London, UK.
-
-// Parts of Boost.Geometry are redesigned from Geodan's Geographic Library
-// (geolib/GGL), copyright (c) 1995-2010 Geodan, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#ifndef BOOST_GEOMETRY_MULTI_ALGORITHMS_CONVEX_HULL_HPP
-#define BOOST_GEOMETRY_MULTI_ALGORITHMS_CONVEX_HULL_HPP
-
-
-#include <boost/geometry/multi/iterators/range_type.hpp>
-#include <boost/geometry/multi/algorithms/detail/for_each_range.hpp>
-
-// Note that this file is, furthermore, empty,
-// there is no specialization necessary
-// as this is in fact done by for_each_range
-
-// Might therefore be obsoleted.
-
-
-#endif // BOOST_GEOMETRY_MULTI_ALGORITHMS_CONVEX_HULL_HPP
Deleted: trunk/boost/geometry/multi/algorithms/difference.hpp
==============================================================================
--- trunk/boost/geometry/multi/algorithms/difference.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
+++ (empty file)
@@ -1,48 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-
-// Copyright (c) 2007-2011 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#ifndef BOOST_GEOMETRY_MULTI_ALGORITHMS_DIFFERENCE_HPP
-#define BOOST_GEOMETRY_MULTI_ALGORITHMS_DIFFERENCE_HPP
-
-
-#include <boost/geometry/algorithms/difference.hpp>
-#include <boost/geometry/multi/core/closure.hpp>
-#include <boost/geometry/multi/core/geometry_id.hpp>
-#include <boost/geometry/multi/core/is_areal.hpp>
-#include <boost/geometry/multi/core/point_order.hpp>
-#include <boost/geometry/multi/algorithms/envelope.hpp>
-#include <boost/geometry/multi/algorithms/num_points.hpp>
-#include <boost/geometry/multi/algorithms/within.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/get_ring.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/get_turns.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/copy_segments.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/copy_segment_point.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/select_rings.hpp>
-#include <boost/geometry/multi/algorithms/detail/sections/range_by_section.hpp>
-#include <boost/geometry/multi/algorithms/detail/sections/sectionalize.hpp>
-
-namespace boost { namespace geometry
-{
-
-
-#ifndef DOXYGEN_NO_DISPATCH
-namespace dispatch
-{
-
-// Currently empty, all done in overlay / assemble
-
-
-
-} // namespace dispatch
-#endif
-
-}} // namespace boost::geometry
-
-
-#endif // BOOST_GEOMETRY_MULTI_ALGORITHMS_DIFFERENCE_HPP
-
Modified: trunk/boost/geometry/multi/algorithms/intersection.hpp
==============================================================================
--- trunk/boost/geometry/multi/algorithms/intersection.hpp (original)
+++ trunk/boost/geometry/multi/algorithms/intersection.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -152,7 +152,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
multi_linestring_tag, multi_linestring_tag, point_tag,
false, false, false,
@@ -178,7 +178,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
linestring_tag, multi_linestring_tag, point_tag,
false, false, false,
@@ -204,7 +204,7 @@
overlay_type OverlayType,
typename Strategy
>
-struct intersection_inserter
+struct intersection_insert
<
multi_linestring_tag, box_tag, linestring_tag,
false, true, false,
Deleted: trunk/boost/geometry/multi/algorithms/union.hpp
==============================================================================
--- trunk/boost/geometry/multi/algorithms/union.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
+++ (empty file)
@@ -1,48 +0,0 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
-
-// Copyright (c) 2007-2011 Barend Gehrels, Amsterdam, the Netherlands.
-
-// Use, modification and distribution is subject to the Boost Software License,
-// Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
-// http://www.boost.org/LICENSE_1_0.txt)
-
-#ifndef BOOST_GEOMETRY_MULTI_ALGORITHMS_UNION_HPP
-#define BOOST_GEOMETRY_MULTI_ALGORITHMS_UNION_HPP
-
-
-#include <boost/geometry/algorithms/union.hpp>
-#include <boost/geometry/multi/core/closure.hpp>
-#include <boost/geometry/multi/core/geometry_id.hpp>
-#include <boost/geometry/multi/core/is_areal.hpp>
-#include <boost/geometry/multi/core/point_order.hpp>
-#include <boost/geometry/multi/algorithms/envelope.hpp>
-#include <boost/geometry/multi/algorithms/num_points.hpp>
-#include <boost/geometry/multi/algorithms/within.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/get_ring.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/get_turns.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/copy_segments.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/copy_segment_point.hpp>
-#include <boost/geometry/multi/algorithms/detail/overlay/select_rings.hpp>
-#include <boost/geometry/multi/algorithms/detail/sections/range_by_section.hpp>
-#include <boost/geometry/multi/algorithms/detail/sections/sectionalize.hpp>
-
-namespace boost { namespace geometry
-{
-
-
-#ifndef DOXYGEN_NO_DISPATCH
-namespace dispatch
-{
-
-// Currently empty, all done in overlay / assemble
-
-
-
-} // namespace dispatch
-#endif
-
-}} // namespace boost::geometry
-
-
-#endif // BOOST_GEOMETRY_MULTI_ALGORITHMS_UNION_HPP
-
Modified: trunk/boost/geometry/multi/multi.hpp
==============================================================================
--- trunk/boost/geometry/multi/multi.hpp (original)
+++ trunk/boost/geometry/multi/multi.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -29,7 +29,6 @@
#include <boost/geometry/multi/algorithms/area.hpp>
#include <boost/geometry/multi/algorithms/centroid.hpp>
#include <boost/geometry/multi/algorithms/clear.hpp>
-#include <boost/geometry/multi/algorithms/convex_hull.hpp>
#include <boost/geometry/multi/algorithms/correct.hpp>
#include <boost/geometry/multi/algorithms/distance.hpp>
#include <boost/geometry/multi/algorithms/envelope.hpp>
@@ -44,7 +43,6 @@
#include <boost/geometry/multi/algorithms/reverse.hpp>
#include <boost/geometry/multi/algorithms/simplify.hpp>
#include <boost/geometry/multi/algorithms/transform.hpp>
-#include <boost/geometry/multi/algorithms/union.hpp>
#include <boost/geometry/multi/algorithms/unique.hpp>
#include <boost/geometry/multi/algorithms/within.hpp>
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/geometry/algorithms/intersection.hpp (original)
+++ trunk/boost/geometry/algorithms/intersection.hpp 2011-04-01 12:38:43 EDT (Fri, 01 Apr 2011)
@@ -11,7 +11,7 @@
#include <boost/geometry/core/coordinate_dimension.hpp>
-#include <boost/geometry/algorithms/intersection_inserter.hpp>
+#include <boost/geometry/algorithms/detail/overlay/intersection_insert.hpp>
#include <boost/geometry/algorithms/intersects.hpp>
@@ -83,7 +83,7 @@
namespace dispatch
{
// By default, all is forwarded to the intersection_inserter-dispatcher
template
<
typename Tag1, typename Tag2, typename TagOut,
@@ -102,7 +102,7 @@
{
typedef typename boost::range_value<GeometryOut>::type OneOut;
- intersection_inserter
+ intersection_insert
<
Tag1, Tag2, typename geometry::tag<OneOut>::type,
geometry::is_areal<Geometry1>::value,
@@ -83,7 +83,7 @@
namespace dispatch
{
-// By default, all is forwarded to the intersection_inserter-dispatcher
+// By default, all is forwarded to the intersection_insert-dispatcher
template
<
Deleted: trunk/boost/geometry/algorithms/intersection_inserter.hpp
==============================================================================